package
Version:
v0.0.0-...-6e90ae1
Opens a new window with list of versions in this module.
Published: Jan 16, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
PluginDir string `json:"pluginDir"`
InstallDir string `json:"installDir"`
PathDir string `json:"pathDir"`
}
Config is the application configuration
GetConfig loads the configuration into a Config struct
Source Files
¶
Click to show internal directories.
Click to hide internal directories.