Documentation
¶
Index ¶
- Variables
- func InstalledVersion(pluginName string, fs afero.Fs) (string, error)
- func InstalledVersionCmd(pluginName string, fs afero.Fs) tea.Cmd
- func Remove(pluginName string, fs afero.Fs) error
- func RemoveCmd(pluginName string, fs afero.Fs) tea.Cmd
- func RemoveEntry(pluginName string, fs afero.Fs) error
- func RemoveEntryCmd(pluginName string, fs afero.Fs) tea.Cmd
- func UpdateEntries(entry Entry, fs afero.Fs) error
- func UpdateEntriesCmd(entry Entry, fs afero.Fs) tea.Cmd
- type Download
- type Entry
- type Metadata
- type NotFoundMsg
- type VersionMsg
Constants ¶
This section is empty.
Variables ¶
var ErrNotFound = errors.New("plugin not found")
Functions ¶
func InstalledVersion ¶
InstalledVersion returns the current version of a plugin that is installed. Returns an ErrNotFound if the version is not found.
func InstalledVersionCmd ¶
InstalledVersionCmd returns a VersionMsg on success, a NotFoundMsg with the plugin name if the plugin isn't found, and an error on failure
func UpdateEntries ¶
UpdateEntries updates the data of an entry if it exists, and adds an entry if it doesn't
Types ¶
type Entry ¶
type NotFoundMsg ¶
NotFoundMsg contains the name of the plugin that is not found
Click to show internal directories.
Click to hide internal directories.